==> cmsmadesimple-1.5.3.tgz: cms/modules/Search/lang/ext/cs_CZ.php <==
<?php
$lang['word'] = 'Slovo';
$lang['count'] = 'Počet';
$lang['confirm_clearstats'] = 'Opravdu chcete permanentně vymazat v&scaron;echny statistiky?';
$lang['clear'] = 'Vymazat';
$lang['statistics'] = 'Statistiky';
$lang['param_action'] = 'Zadejte pracovn&iacute; m&oacute;d modulu.  Přijateln&eacute; hodnoty jsou &#039;default&#039; a &#039;keywords&#039;.  Keywords může b&yacute;t použito pro generov&aacute;n&iacute; č&aacute;rkou oddělen&eacute;ho seznamu slov vhodn&yacute;ch pro keyword meta tag.';
$lang['param_count'] = 'Při použit&iacute; keywords, tento parametr omezuje v&yacute;stup na zadan&yacute; počet slov';
$lang['param_pageid'] = 'Použiteln&eacute; pouze s keywords, tento parametr může b&yacute;t použit pro zad&aacute;n&iacute; rozd&iacute;ln&eacute;ho id str&aacute;nky pro v&yacute;pis v&yacute;sledků';
$lang['param_inline'] = 'Pokud ano, v&yacute;stup z vyhled&aacute;vac&iacute;ho formul&aacute;ře nahrad&iacute; původn&iacute; obsah &#039;search&#039; tagu v původn&iacute;m obsahov&eacute;m bloku. Použ&iacute;vejte tento parametr pokud &scaron;ablona m&aacute; v&iacute;ce obsahov&yacute;ch bloků a nechcete aby v&yacute;stup vyhled&aacute;v&aacute;n&iacute; nahradil v&yacute;choz&iacute; obsahov&yacute; blok';
$lang['param_passthru'] = 'Postoupit jmenovan&eacute; parametry udan&yacute;m modulům. Form&aacute;t každ&eacute;ho parametru je: &quot;passtru_MODULENAME_PARAMNAME=&#039;hodnota&#039;&quot; např.: passthru_News_detailpage=&#039;newsdetails&#039;&quot;';
$lang['param_modules'] = 'Omezit v&yacute;sledky hled&aacute;n&iacute; na indexovan&eacute; hodnoty z udan&eacute;ho (č&aacute;rkou oddělen&eacute;ho) seznamu modulů';
$lang['searchsubmit'] = 'Odeslat';
$lang['search'] = 'Hledat';
$lang['param_submit'] = 'Text pro vložen&iacute; do odes&iacute;lac&iacute;ho tlač&iacute;tka';
$lang['param_searchtext'] = 'Text pro vložen&iacute; do vyhled&aacute;vac&iacute;ho pole';
$lang['prompt_searchtext'] = 'V&yacute;choz&iacute; text pro vyhled&aacute;v&aacute;n&iacute;';
$lang['param_resultpage'] = 'Str&aacute;nka pro zobrazen&iacute; v&yacute;sledků hled&aacute;n&iacute;. Toto může b&yacute;t jak alias str&aacute;nky tak id. Použ&iacute;v&aacute; se pro zobrazen&iacute; v&yacute;sledků v jin&eacute; &scaron;abloně než formul&aacute;ř pro vyhled&aacute;v&aacute;n&iacute;';
$lang['description'] = 'Modul pro prohled&aacute;v&aacute;n&iacute; str&aacute;nek a obsahu jin&yacute;ch modulů.';
$lang['reindexallcontent'] = 'Přeindexovat ve&scaron;ker&yacute; obsah';
$lang['reindexcomplete'] = 'Přeindexov&aacute;n&iacute; hotovo';
$lang['stopwords'] = 'Zak&aacute;zan&aacute; slova';
$lang['searchresultsfor'] = 'Hledan&yacute; v&yacute;raz: ';
$lang['noresultsfound'] = 'Nic nenalezeno';
$lang['timetaken'] = 'Čas';
$lang['usestemming'] = 'Použ&iacute;t dělen&iacute; slov (pouze v angličtině)';
$lang['searchtemplate'] = '&Scaron;ablona pro vyhled&aacute;v&aacute;n&iacute;';
$lang['resulttemplate'] = '&Scaron;ablona pro v&yacute;sledky';
$lang['submit'] = 'Odeslat';
$lang['sysdefaults'] = 'Nastavit v&yacute;choz&iacute;';
$lang['searchtemplateupdated'] = '&Scaron;ablona pro vyhled&aacute;v&aacute;n&iacute; aktualizov&aacute;na';
$lang['resulttemplateupdated'] = '&Scaron;ablona pro v&yacute;sledky aktualizov&aacute;na';
$lang['restoretodefaultsmsg'] = 'Tato operace nastav&iacute; obsah &scaron;ablon na v&yacute;choz&iacute;. Opravdu ji chcete prov&eacute;st?';
$lang['options'] = 'Volby';
$lang['eventdesc-SearchInitiated'] = 'Odeslat po startu hled&aacute;n&iacute;.';
$lang['eventdesc-SearchCompleted'] = 'Odeslat po dokončen&iacute; vyhled&aacute;v&aacute;n&iacute;.';
$lang['eventdesc-SearchItemAdded'] = 'Odeslat po indexaci nov&eacute; položky.';
$lang['eventdesc-SearchItemDeleted'] = 'Odeslat po smaz&aacute;n&iacute; položky z indexu.';
$lang['eventdesc-SearchAllItemsDeleted'] = 'Odeslat po smaz&aacute;n&iacute; v&scaron;ech položek z indexu.';
$lang['eventhelp-SearchInitiated'] = '<p>Odeslat po startu hled&aacute;n&iacute;.</p>
<h4>Parametry</h4>
<ol>
<li>Text pro vyhled&aacute;v&aacute;n&iacute;.</li>
</ol>
';
$lang['eventhelp-SearchCompleted'] = '<p>Odeslat po dokončen&iacute; vyhled&aacute;v&aacute;n&iacute;.</p>
<h4>Parametry</h4>
<ol>
<li>Text, ktery byl hled&aacute;n.</li>
<li>Pole v&yacute;sledků.</li>
</ol>
';
$lang['eventhelp-SearchItemAdded'] = '<p>Odeslat po indexaci nov&eacute; položky.</p>
<h4>Parametry</h4>
<ol>
<li>Jm&eacute;no modulu.</li>
<li>Id položky.</li>
<li>Dodatečn&yacute; atribut.</li>
<li>Content to index and add.</li>
</ol>
';
$lang['eventhelp-SearchItemDeleted'] = '<p>Odeslat po smaz&aacute;n&iacute; položky z indexu.</p>
<h4>Parametry</h4>
<ol>
<li>Jm&eacute;no modulu.</li>
<li>Id položky.</li>
<li>Dodatečn&yacute; atribut.</li>
</ol>
';
$lang['eventhelp-SearchAllItemsDeleted'] = '<p>Odeslat po smaz&aacute;n&iacute; v&scaron;ech položek z indexu.</p>
<h4>Parametry</h4>
<ul>
<li>Ž&aacute;dn&eacute;</li>
</ul>
';
$lang['help'] = '<h3>What does this do?</h3>
<p>Search is a module for searching &quot;core&quot; content along with certain registered modules.  You put in a word or two and it gives you back matching, relevent results.</p>
<h3>How do I use it?</h3>
<p>The easiest way to use it is with the {search} wrapper tag (wraps the module in a tag, to simplify the syntax). This will insert the module into your template or page anywhere you wish, and display the search form.  The code would look something like: <code>{search}</code></p>
<h4>How do i prevent certain content from being indexed</h4>
<p>The search module will not search any &quot;inactive&quot; pages. However on occasion, when you are using the CustomContent module, or other smarty logic to show different content to different groups of users, it may be advisiable to prevent the entire page from being indexed even when it is live.  To do this include the following tag anywhere on the page <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> When the search module sees this tag in the page it will not index any content for that page.</p>
<p>The <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> tag can be placed in the template as well.  if this is done, none of the pages attached to that template will be indexed.  Those pages will be re-indexed if the tag is removed</p>';
$lang['changelog'] = '<ul>
<li>1.1 - Original release</li>
<li>1.2 - April 2007 (calguy1000)
  <p>Added the ability to limit results to certain modules,and added the ability to pass parameters through to the various modules to allow different formatting of the output.</p>
  <p>Modified so that the search module could be used in non default content blocks.</p>
</li>
<li>1.3 - May 2007 (calguy1000)
  <p>Adds calls to SetParameterType</p>
</li>
<li>1.4 - Nov 2007 (calguy1000)
  <p>Adds the keywords action.</p>
  <p>Fixes a problem with using the resultpage parameter to a page that&#039;s template was dramatically different.</p>
</li>
<li>1.4.1 - Nov 2007 (calguy1000)
  <p>Minor fixes so that php tags, and punctuation characters are not indexed.</p>
  <p>Fix the VisibleToAdminUser method</p>
</li>
<li>1.5 - Mar 2008 (calguy1000)
  <p>Now gather statistics about the top most 50 frequently searched words.</p>
  <p>Addd the ability to display the statistics and clear them from the admin panel.</p>
  <p>Make it easier to style the search button, and its label.</p>
  <p>Now only index active pages</p>
</li>
<li>1.5.1 - July 2008 (calguy1000)
  <p>Minor changes to the template to restore behaviour that was there before 1.5</p>
  <p>Now escape any search term characters that have special meanings in regular expressions</p>
  <p>Minor optimizations and tweaks</p>
</li>
</ul>';
$lang['utmz'] = '156861353.1228210443.132.48.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/projects/formbrowser|utmcmd=referral';
$lang['utma'] = '156861353.1164120856.1187941896.1228205216.1228210443.132';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/Search/lang/ext/cs_CZ.php <==
<?php
$lang['search_method'] = 'Kompatibilita pěkn&yacute;ch url s metodou POST, v&yacute;choz&iacute; hodnota je vždy GET, pro spr&aacute;vnou funkčnost vložte {search search_method=&quot;post&quot;} ';
$lang['export_to_csv'] = 'Exportovat do CSV';
$lang['prompt_savephrases'] = 'Sledovat vyhled&aacute;van&eacute; fr&aacute;ze, ne samostatn&aacute; slova';
$lang['word'] = 'Slovo';
$lang['count'] = 'Počet';
$lang['confirm_clearstats'] = 'Opravdu chcete permanentně vymazat v&scaron;echny statistiky?';
$lang['clear'] = 'Vymazat';
$lang['statistics'] = 'Statistiky';
$lang['param_action'] = 'Zadejte pracovn&iacute; m&oacute;d modulu.  Přijateln&eacute; hodnoty jsou &#039;default&#039; a &#039;keywords&#039;.  Keywords může b&yacute;t použito pro generov&aacute;n&iacute; č&aacute;rkou oddělen&eacute;ho seznamu slov vhodn&yacute;ch pro keyword meta tag.';
$lang['param_count'] = 'Při použit&iacute; keywords, tento parametr omezuje v&yacute;stup na zadan&yacute; počet slov';
$lang['param_pageid'] = 'Použiteln&eacute; pouze s keywords, tento parametr může b&yacute;t použit pro zad&aacute;n&iacute; rozd&iacute;ln&eacute;ho id str&aacute;nky pro v&yacute;pis v&yacute;sledků';
$lang['param_inline'] = 'Pokud ano, v&yacute;stup z vyhled&aacute;vac&iacute;ho formul&aacute;ře nahrad&iacute; původn&iacute; obsah &#039;search&#039; tagu v původn&iacute;m obsahov&eacute;m bloku. Použ&iacute;vejte tento parametr pokud &scaron;ablona m&aacute; v&iacute;ce obsahov&yacute;ch bloků a nechcete aby v&yacute;stup vyhled&aacute;v&aacute;n&iacute; nahradil v&yacute;choz&iacute; obsahov&yacute; blok';
$lang['param_passthru'] = 'Postoupit jmenovan&eacute; parametry udan&yacute;m modulům. Form&aacute;t každ&eacute;ho parametru je: &quot;passtru_MODULENAME_PARAMNAME=&#039;hodnota&#039;&quot; např.: passthru_News_detailpage=&#039;newsdetails&#039;&quot;';
$lang['param_modules'] = 'Omezit v&yacute;sledky hled&aacute;n&iacute; na indexovan&eacute; hodnoty z udan&eacute;ho (č&aacute;rkou oddělen&eacute;ho) seznamu modulů';
$lang['searchsubmit'] = 'Odeslat';
$lang['search'] = 'Hledat';
$lang['param_submit'] = 'Text pro vložen&iacute; do odes&iacute;lac&iacute;ho tlač&iacute;tka';
$lang['param_searchtext'] = 'Text pro vložen&iacute; do vyhled&aacute;vac&iacute;ho pole';
$lang['prompt_searchtext'] = 'V&yacute;choz&iacute; text pro vyhled&aacute;v&aacute;n&iacute;';
$lang['param_resultpage'] = 'Str&aacute;nka pro zobrazen&iacute; v&yacute;sledků hled&aacute;n&iacute;. Toto může b&yacute;t jak alias str&aacute;nky tak id. Použ&iacute;v&aacute; se pro zobrazen&iacute; v&yacute;sledků v jin&eacute; &scaron;abloně než formul&aacute;ř pro vyhled&aacute;v&aacute;n&iacute;';
$lang['prompt_alpharesults'] = 'Tř&iacute;dit v&yacute;sledky podle abecedy m&iacute;sto v&aacute;hy';
$lang['description'] = 'Modul pro prohled&aacute;v&aacute;n&iacute; str&aacute;nek a obsahu jin&yacute;ch modulů.';
$lang['reindexallcontent'] = 'Přeindexovat ve&scaron;ker&yacute; obsah';
$lang['reindexcomplete'] = 'Přeindexov&aacute;n&iacute; hotovo';
$lang['stopwords'] = 'Zak&aacute;zan&aacute; slova';
$lang['searchresultsfor'] = 'Hledan&yacute; v&yacute;raz: ';
$lang['noresultsfound'] = 'Nic nenalezeno';
$lang['timetaken'] = 'Čas';
$lang['usestemming'] = 'Použ&iacute;t dělen&iacute; slov (pouze v angličtině)';
$lang['searchtemplate'] = '&Scaron;ablona pro vyhled&aacute;v&aacute;n&iacute;';
$lang['resulttemplate'] = '&Scaron;ablona pro v&yacute;sledky';
$lang['submit'] = 'Odeslat';
$lang['sysdefaults'] = 'Nastavit v&yacute;choz&iacute;';
$lang['searchtemplateupdated'] = '&Scaron;ablona pro vyhled&aacute;v&aacute;n&iacute; aktualizov&aacute;na';
$lang['resulttemplateupdated'] = '&Scaron;ablona pro v&yacute;sledky aktualizov&aacute;na';
$lang['restoretodefaultsmsg'] = 'Tato operace nastav&iacute; obsah &scaron;ablon na v&yacute;choz&iacute;. Opravdu ji chcete prov&eacute;st?';
$lang['options'] = 'Volby';
$lang['eventdesc-SearchInitiated'] = 'Odeslat po startu hled&aacute;n&iacute;.';
$lang['eventdesc-SearchCompleted'] = 'Odeslat po dokončen&iacute; vyhled&aacute;v&aacute;n&iacute;.';
$lang['eventdesc-SearchItemAdded'] = 'Odeslat po indexaci nov&eacute; položky.';
$lang['eventdesc-SearchItemDeleted'] = 'Odeslat po smaz&aacute;n&iacute; položky z indexu.';
$lang['eventdesc-SearchAllItemsDeleted'] = 'Odeslat po smaz&aacute;n&iacute; v&scaron;ech položek z indexu.';
$lang['eventhelp-SearchInitiated'] = '<p>Odeslat po startu hled&aacute;n&iacute;.</p>
<h4>Parametry</h4>
<ol>
<li>Text pro vyhled&aacute;v&aacute;n&iacute;.</li>
</ol>
';
$lang['eventhelp-SearchCompleted'] = '<p>Odeslat po dokončen&iacute; vyhled&aacute;v&aacute;n&iacute;.</p>
<h4>Parametry</h4>
<ol>
<li>Text, ktery byl hled&aacute;n.</li>
<li>Pole v&yacute;sledků.</li>
</ol>
';
$lang['eventhelp-SearchItemAdded'] = '<p>Odeslat po indexaci nov&eacute; položky.</p>
<h4>Parametry</h4>
<ol>
<li>Jm&eacute;no modulu.</li>
<li>Id položky.</li>
<li>Dodatečn&yacute; atribut.</li>
<li>Content to index and add.</li>
</ol>
';
$lang['eventhelp-SearchItemDeleted'] = '<p>Odeslat po smaz&aacute;n&iacute; položky z indexu.</p>
<h4>Parametry</h4>
<ol>
<li>Jm&eacute;no modulu.</li>
<li>Id položky.</li>
<li>Dodatečn&yacute; atribut.</li>
</ol>
';
$lang['eventhelp-SearchAllItemsDeleted'] = '<p>Odeslat po smaz&aacute;n&iacute; v&scaron;ech položek z indexu.</p>
<h4>Parametry</h4>
<ul>
<li>Ž&aacute;dn&eacute;</li>
</ul>
';
$lang['help'] = '<h3>What does this do?</h3>
<p>Search is a module for searching &quot;core&quot; content along with certain registered modules.  You put in a word or two and it gives you back matching, relevent results.</p>
<h3>How do I use it?</h3>
<p>The easiest way to use it is with the {search} wrapper tag (wraps the module in a tag, to simplify the syntax). This will insert the module into your template or page anywhere you wish, and display the search form.  The code would look something like: <code>{search}</code></p>
<h4>How do i prevent certain content from being indexed</h4>
<p>The search module will not search any &quot;inactive&quot; pages. However on occasion, when you are using the CustomContent module, or other smarty logic to show different content to different groups of users, it may be advisiable to prevent the entire page from being indexed even when it is live.  To do this include the following tag anywhere on the page <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> When the search module sees this tag in the page it will not index any content for that page.</p>
<p>The <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> tag can be placed in the template as well.  if this is done, none of the pages attached to that template will be indexed.  Those pages will be re-indexed if the tag is removed</p>';
$lang['utma'] = '156861353.3769824904990279700.1249913289.1249913289.1249913289.1';
$lang['utmb'] = '156861353.1.10.1249913289';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1249913289.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['qca'] = '1229762881-19854751-99654968';
$lang['qcb'] = '1368372279';
?>
